@@ -2,6 +2,7 @@ import collections
 import datetime
 
 from django.conf import settings
+from django.core.exceptions import ObjectDoesNotExist
 from django.db import models
 
 STATUS_CHOICES = (
@@ -94,9 +95,9 @@ class WordPressModel(models.Model):
 class OptionManager(WordPressManager):
     def get_value(self, name):
         try:
-            o = Option.objects.get(name=name)
+            o = self.get(name=name)
             return o.value
-        except Option.DoesNotExist:
+        except ObjectDoesNotExist:
             pass
 
 
@@ -197,7 +198,7 @@ class PostManager(WordPressManager):
     """
 
     def _by_status(self, status, post_type='post'):
-        return Post.objects.filter(status=status, post_type=post_type).select_related().prefetch_related('meta')
+        return self.filter(status=status, post_type=post_type).select_related().prefetch_related('meta')
 
     def drafts(self, post_type='post'):
         return self._by_status('draft', post_type)
@@ -219,9 +220,9 @@ class PostManager(WordPressManager):
             tx = Taxonomy.objects.filter(name=taxonomy, term__slug__in=terms)
             post_ids = TermTaxonomyRelationship.objects.filter(term_taxonomy__in=tx).values_list('object_id', flat=True)
 
-            return Post.objects.published().filter(pk__in=post_ids)
+            return self.published().filter(pk__in=post_ids)
         except Taxonomy.DoesNotExist:
-            return Post.objects.none()
+            return self.none()
 
     def from_path(self, path):
 
@@ -236,8 +237,8 @@ class PostManager(WordPressManager):
         }
 
         try:
-            return Post.objects.published().get(**params)
-        except Post.DoesNotExist:
+            return self.published().get(**params)
+        except ObjectDoesNotExist:
             pass  # fall through to return None
 
 
@@ -290,7 +291,8 @@ class Post(WordPressModel):
 #    category_id = models.IntegerField(db_column='post_category')
 
     # other various lame fields
-    parent = models.ForeignKey('self', related_name="children", db_column="post_parent", blank=True, null=True)
+    parent_id = models.IntegerField(default=0, db_column="post_parent")
+    # parent = models.ForeignKey('self', related_name="children", db_column="post_parent", blank=True, null=True)
     menu_order = models.IntegerField(default=0)
     mime_type = models.CharField(max_length=100, db_column='post_mime_type')
 
@@ -299,27 +301,19 @@ class Post(WordPressModel):
 
     class Meta:
         db_table = '%s_posts' % TABLE_PREFIX
+        get_latest_by = 'post_date'
         ordering = ["-post_date"]
         managed = False
 
     def __unicode__(self):
         return self.title
 
-    def categories(self):
-        return self._get_terms("category")
-
-    def attachments(self):
-        for post in self._get_children():
-            if post.post_type == 'attachment':
-                yield {
-                    'id': post.id,
-                    'slug': post.slug,
-                    'timestamp': post.post_date,
-                    'description': post.content,
-                    'title': post.title,
-                    'guid': post.guid,
-                    'mimetype': post.mime_type,
-                }
+    def save(self, **kwargs):
+        if self.parent_id is None:
+            self.parent_id = 0
+        super(Post, self).save(**kwargs)
+        self.child_cache = None
+        self.term_cache = None
 
     @models.permalink
     def get_absolute_url(self):
@@ -330,12 +324,11 @@ class Post(WordPressModel):
             self.slug
         ))
 
-    def tags(self):
-        return self._get_terms("post_tag")
+    # cache stuff
 
     def _get_children(self):
         if self.child_cache is None:
-            self.child_cache = list(self.children.all())
+            self.child_cache = list(Post.objects.filter(parent_id=self.pk))
         return self.child_cache
 
     def _get_terms(self, taxonomy):
@@ -359,6 +352,44 @@ class Post(WordPressModel):
 
         return self.term_cache.get(taxonomy)
 
+    # properties
+
+    @property
+    def children(self):
+        return self._get_children()
+
+    @property
+    def parent(self):
+        if self.parent_id:
+            return Post.objects.get(pk=self.parent_id)
+
+    @parent.setter
+    def parent(self, post):
+        if post.pk is None:
+            raise ValueError('parent post must have an ID')
+        self.parent_id = post.pk
+
+    # related objects
+
+    def categories(self):
+        return self._get_terms("category")
+
+    def attachments(self):
+        for post in self._get_children():
+            if post.post_type == 'attachment':
+                yield {
+                    'id': post.id,
+                    'slug': post.slug,
+                    'timestamp': post.post_date,
+                    'description': post.content,
+                    'title': post.title,
+                    'guid': post.guid,
+                    'mimetype': post.mime_type,
+                }
+
+    def tags(self):
+        return self._get_terms("post_tag")
+
 
 class PostMeta(WordPressModel):
     """
